@@ -1,5 +1,6 @@
 from __future__ import division, print_function
 
+import time
 from mock import MagicMock
 import pytest
 import numpy as np
@@ -31,6 +32,9 @@ class TestScatterDensity(object):
         self.fig = plt.figure(figsize=(3, 3))
         self.ax = self.fig.add_axes([0.13, 0.13, 0.8, 0.8])
 
+    def teardown_method(self, method):
+        plt.close(self.fig)
+
     @pytest.mark.mpl_image_compare(style={}, baseline_dir=baseline_dir)
     def test_default(self):
         a = ScatterDensityArtist(self.ax, self.x1, self.y1)
@@ -90,7 +94,7 @@ class TestScatterDensity(object):
         self.ax.add_artist(a)
         self.ax.figure.canvas.toolbar = MagicMock()
         self.ax.figure.canvas.toolbar.mode = 'pan/zoom'
-        a.downres()
+        a.on_press()
         self.ax.set_xlim(0.1, 3.)
         self.ax.set_ylim(0.1, 3.)
         if log:
@@ -134,7 +138,7 @@ class TestScatterDensity(object):
         self.ax.set_ylim(-6.5, 6.5)
         self.ax.figure.canvas.toolbar = MagicMock()
         self.ax.figure.canvas.toolbar.mode = 'pan/zoom'
-        a.downres()
+        a.on_press()
         return self.fig
 
     @pytest.mark.mpl_image_compare(style={}, baseline_dir=baseline_dir)
@@ -200,7 +204,7 @@ class TestScatterDensity(object):
         # draw when calling figure.canvas.draw()
         self.ax.figure.savefig(tmpdir.join('test1.png').strpath)
         assert not a.stale
-        a.downres()
+        a.on_press()
         assert a.stale
 
         a = ScatterDensityArtist(self.ax, self.x1, self.y1, downres_factor=1)
@@ -211,7 +215,7 @@ class TestScatterDensity(object):
         # draw when calling figure.canvas.draw()
         self.ax.figure.savefig(tmpdir.join('test2.png').strpath)
         assert not a.stale
-        a.downres()
+        a.on_press()
         assert not a.stale
 
     def test_default_dpi(self, tmpdir):
@@ -238,5 +242,50 @@ class TestScatterDensity(object):
         # draw when calling figure.canvas.draw()
         self.ax.figure.savefig(tmpdir.join('test.png').strpath)
         assert not a.stale
-        a.downres()
+        a.on_press()
         assert not a.stale
+
+
+def test_resize_qt():
+
+    # This test just ensures that the code runs, but doesn't check for now
+    # that the behavior is correct.
+
+    from PyQt5.QtWidgets import QMainWindow
+
+    from matplotlib.figure import Figure
+    from matplotlib.backends.backend_qt5 import FigureManagerQT
+    from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg
+
+    fig = Figure()
+    canvas = FigureCanvasQTAgg(fig)
+    canvas.manager = FigureManagerQT(canvas, 0)  # noqa
+    ax = fig.add_subplot(1, 1, 1)
+
+    from matplotlib.backends.backend_qt5 import qApp
+
+    window = QMainWindow()
+    window.setCentralWidget(canvas)
+    window.show()
+
+    x1 = np.random.normal(0, 1, 10000000)
+    y1 = np.random.normal(0, 1, 10000000)
+
+    a = ScatterDensityArtist(ax, x1, y1)
+    ax.add_artist(a)
+
+    canvas.draw()
+    assert not a.stale
+
+    window.resize(300, 300)
+    assert a.stale
+
+    qApp.processEvents()
+    assert not a.stale
+
+    start = time.time()
+    while time.time() - start < 1:
+        qApp.processEvents()
+
+    a.remove()
+    qApp.processEvents()
